import { CfnTrigger } from 'aws-cdk-lib/aws-glue';
import { IConstruct } from 'constructs';
import { IJob, ITriggerAction } from '../..';
import { WorkflowActionBase, WorkflowActionOptions } from './action-base';
export interface BookmarkRange {
    readonly from: string;
    readonly to: string;
}
export declare class BookmarkConfiguration {
    readonly value: string;
    readonly range?: BookmarkRange | undefined;
    static disable(): BookmarkConfiguration;
    static enable(): BookmarkConfiguration;
    static pause(range?: BookmarkRange): BookmarkConfiguration;
    static of(value: string, range?: BookmarkRange): BookmarkConfiguration;
    private constructor();
}
/**
 * Configuration options for the WorkflowJobAction class.
 */
export interface WorkflowJobActionOptions extends WorkflowActionOptions {
    readonly bookmarkConfiguration?: BookmarkConfiguration;
}
/**
 * Represents the configuration for a job that will be triggered as part of a
 * workflow.
 */
export declare class WorkflowJobAction extends WorkflowActionBase implements ITriggerAction {
    /**
     * The Glue job to be triggered as part of the workflow.
     *
     * @group Inputs
     */
    readonly job: IJob;
    /**
     * Creates a new instance of the WorkflowJobAction class.
     *
     * @param job The job that should be triggered as part of the workflow.
     * @param options The options affecting how the job should be triggered.
     */
    constructor(job: IJob, options?: WorkflowJobActionOptions);
    /**
     * Associates this action with a resource that is configuring a Glue trigger.
     *
     * @param scope The construct configuring the trigger that this action will
     * be used in.
     * @returns The configuration that can be used to configure the underlying
     * trigger resource.
     */
    bind(scope: IConstruct): CfnTrigger.ActionProperty;
}
